@@ -1,4 +1,4 @@
-def printList (the_list, level):
+def printList (the_list, level = 0):
     for each_list in the_list:
         if isinstance(each_list, list):#默认递归不能超过100
             printList(each_list, level + 1)
